;; Generated package description from scroll-restore.el  -*- no-byte-compile: t -*-
(define-package "scroll-restore" "1.0.0.20221212.230219" "restore original position after scrolling" 'nil :commit "ca84c472d45ea91be89f7f6f5f8669fe61824e81" :url "https://elpa.gnu.org/packages/scroll-restore.html" :authors '(("Martin Rudalics" . "rudalics@gmx.at")) :maintainer '("Martin Rudalics" . "rudalics@gmx.at") :keywords '("scrolling"))
